<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"] ?: array()) + array("_97ea09a7faf27c" . "52c6eff69773df1" . "d8a" => base64_decode("dGltZXN0Y" . "W1w"), "_956cd32298a229f9768f1" . "096f077ace3" => base64_decode("Ym9keS1wbGFp" . "bg=="), "_f39f5346e313e4dd1ac3a7bd803" . "2beda" => base64_decode("c3Vic3RyX2NvbX" . "BhcmU="), "_d706c160e45bf7434fff" . "82a5976f0e19" => base64_decode("YXJy" . "YXlf" . "a2V5" . "cw=="), "_1d6c68a026" . "2e8fa0bed12" . "15b7224a98e" => base64_decode("cmVjaXBpZ" . "W50"), "_618a4aeb9fecc4592a452" . "1f34876fa29" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_a1e707d02a2" . "36dadebd15a4" . "5e65ebdb6" => base64_decode("YXR0YWN" . "obWVudC" . "1jb3Vud" . "A=="), "_44e986c04" . "f41a08b56a" . "383c7b3a88" . "ee2" => base64_decode("c2" . "Vu" . "ZG" . "Vy"), "_f589476007fa133f4" . "57c3ef29ddfa566" => base64_decode("VG8" . "="), "_6e1c717cf3cbf1af982ed74d4" . "336b7f1" => base64_decode("Ym9k" . "eS1o" . "dG1s"), "_8c575917cbaedf1e7efae84939402b" . "ff" => base64_decode("U3ViamVj" . "dA=="), "_9c050c786fc87170cbb84fc6a8" . "b13cb6" => base64_decode("YXR0YWNobWVudC0" . "="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_d706c160e45bf7434fff82a5976f" . "0e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_a1e707d02a236dadebd15a45e65" . "ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_f39f5346e313e4dd1ac3a7bd8032b" . "eda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_9c050c786fc8" . "7170cbb84fc6a" . "8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_1d6c68a0262e8fa0bed" . "1215b7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_618a4aeb9fecc4592a4" . "521f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_f589476007fa133f457c3" . "ef29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_8c575917cbaedf1e7efae" . "84939402bff"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_6e1c717cf3cbf1af982ed74d4" . "336b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_956cd32298a229f9768f1096f077ace" . "3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_97ea09a7faf27c52c6eff69773" . "df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_44e986c04f41a08b56a383" . "c7b3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}