<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array("_c35473364fa7a" . "050299058f332e" . "c29c1" => base64_decode("ZXhjZX" . "B0aW9u"), "_5d40a2cf1c525fb252bf5599e3" . "39fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZCBmb3IgbWFpbDsgc3ViamV" . "jdCAn"), "_f656816961e8573806141c558b18" . "4fe2" => base64_decode("c3ViamVjdA" . "=="), "proj" . "ect_" . "id" => base64_decode("cHJvam" . "VjdF9p" . "ZA=="), "_a3d82c5df38e194c9c73e3ccb" . "4223bbc" => base64_decode("ZW1haWxfZGF0YQ=" . "="), "_e608e5b5c4c34a67ba97ef84c1" . "e16199" => base64_decode("Jw" . "=="), "_460e1aeb3113a1676ce59a8" . "f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc3MgZW1haWwgZm9yIGluZm9jYXB0dXJlIHB" . "yb2plY3Q="), "_9b16fa2683095e67d7c8b26" . "5a8081d0b" => base64_decode("TWFpbFJlY2Vp" . "dmVkRXZlbnRS" . "ZWNlaXZlcg=="), "_03b1f0cee835582d11" . "58dce2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCBy" . "ZWNlaXZlZCBzdWJzY3JpYmVy"), "_618a4aeb9fecc4592a4521f34876f" . "a29" => base64_decode("ZnJvbQ" . "=="), "_376d30c40857357a4d4cbb1" . "ffaa25817" => base64_decode("dG8" . "="), "_ced92d7b391285c8a26846f1f4bd" . "3128" => base64_decode("Ym9keV90ZX" . "h0"), "_67a0d624aebcceb0ab" . "d5ce56a53ff06f" => base64_decode("ZGF0Z" . "Q=="), "_bfda889b74ea561b14" . "325e30e7d75426" => base64_decode("Ym9keV" . "9odG1s"));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_9b16fa2683095e67d" . "7c8b265a8081d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_03b1f0cee835582d11" . "58dce2678b505c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_5d40a2cf1c525fb252bf5599e" . "339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_e608e5b5c4" . "c34a67ba97e" . "f84c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_618a4aeb9fecc4592a4521f3487" . "6fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_376d30c4085735" . "7a4d4cbb1ffaa25" . "817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_f656816961e85738" . "06141c558b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_ced92d7b391285c8a26846f1f4bd312" . "8"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_bfda889b74ea561b14325e30" . "e7d75426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_67a0d624aebcceb0a" . "bd5ce56a53ff06f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_460e1aeb" . "3113a1676" . "ce59a8f40" . "431d5c"], [$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["projec" . "t_id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_a3d82c5df38e194" . "c9c73e3ccb4223bb" . "c"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_c35473364fa7a050299058f332ec" . "29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}